@@ -16,9 +16,14 @@
 
 #include "metkit/codes/GribHandle.h"
 
+#include "eccodes.h"
+
 namespace metkit {
 namespace codes {
 
+
+//----------------------------------------------------------------------------------------------------------------------
+
 BufrContent::BufrContent(codes_handle* handle, bool delete_handle): CodesContent(handle, delete_handle) {}
 
 BufrContent::BufrContent(const codes_handle* handle):
@@ -28,6 +33,8 @@ BufrContent::BufrContent(const codes_handle* handle):
 BufrContent::~BufrContent() {}
 
 
+//----------------------------------------------------------------------------------------------------------------------
+
 eckit::message::MessageContent* BufrContent::transform(const eckit::StringDict& dict) const {
     codes_handle* h = codes_handle_clone(handle_);
 
@@ -53,6 +60,9 @@ eckit::message::MessageContent* BufrContent::transform(const eckit::StringDict&
     return new BufrContent(h);
 }
 
+
+//----------------------------------------------------------------------------------------------------------------------
+
 }  // namespace close
 }  // namespace metkit
 
