@@ -12,43 +12,65 @@
 
 #include "eccodes.h"
 
-
 #include "eckit/config/Resource.h"
-#include "eckit/message/Message.h"
 #include "eckit/io/PeekHandle.h"
+#include "eckit/log/Log.h"
+#include "eckit/message/Message.h"
 
-#include "metkit/codes/MallocDataContent.h"
 #include "metkit/codes/GribHandle.h"
+#include "metkit/codes/MallocCodesContent.h"
 
 namespace metkit {
 namespace codes {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-CodesSplitter::CodesSplitter(eckit::PeekHandle& handle):
+CodesSplitter::CodesSplitter(eckit::PeekHandle& handle) :
     Splitter(handle) {}
 
 CodesSplitter::~CodesSplitter() {}
 
 static long readcb(void* data, void* buffer, long len) {
     eckit::DataHandle* handle = reinterpret_cast<eckit::DataHandle*>(data);
-    return handle->read(buffer, len);
+    try {
+        long r = handle->read(buffer, len);
+        // DataHandle is returning 0 on EOF. Codes expects -1 for EOF.
+        return (r == 0) ? -1 : r;
+    }
+    catch (const std::exception& e) {
+        eckit::Log::error() << "Exception thrown in CodesSplitter::readcb callback: " << e.what() << "." << std::endl
+                            << " This may cause unexpected behaviour. Returning -2 instead." << std::endl;
+        // Return negative other from -1 to signalize error.
+        return -2;
+    }
+    catch (...) {
+        eckit::Log::error() << "Unknown exception occured in CodesSplitter::readcb callback. This may cause unexpected behaviour. Returning -2 instead." << std::endl;
+        // Return negative other from -1 to signalize error.
+        return -2;
+    }
 }
 
 eckit::message::Message CodesSplitter::next() {
     size_t size;
-    int err = 0;
-    void *data = wmo_read_any_from_stream_malloc(&handle_, &readcb, &size, &err);
+    int err    = 0;
+    void* data = wmo_read_any_from_stream_malloc(&handle_, &readcb, &size, &err);
 
-    if(err != 0 and err != GRIB_END_OF_FILE) {
+    if (err != 0 and err != GRIB_END_OF_FILE) {
+        if (data) {
+            ::free(data);
+        }
+        if (err == GRIB_WRONG_LENGTH && handle_.canSeek()) {
+            eckit::Offset off = handle_.position() - eckit::Length(size);
+            handle_.seek((off < eckit::Offset(0) ? eckit::Offset(0) : off) + eckit::Offset(4));
+        }
         CODES_CALL(err);
     }
-    
-    if(!data) {
+
+    if (!data) {
         return eckit::message::Message();
     }
 
-    return eckit::message::Message(new MallocDataContent(data, size, 0));
+    return eckit::message::Message(new MallocCodesContent(data, size, 0));
 }
 
 void CodesSplitter::print(std::ostream& s) const {
@@ -63,7 +85,7 @@ void CodesSplitter::print(std::ostream& s) const {
 namespace eckit {
 namespace message {
 
-template<>
+template <>
 bool SplitterBuilder<metkit::codes::CodesSplitter>::match(eckit::PeekHandle& handle) const {
 
     unsigned char c0 = handle.peek(0);
