@@ -85,8 +85,9 @@ class SimpleCallback : public BaseCallbackConnection {
 public:
 
     SimpleCallback() :
-        callbackEndpoint_(net::IPAddress::hostAddress(callback_.localHost()).asString(), callback_.localPort()) {
-        LOG_DEBUG_LIB(LibMetkit) << "Simple callback. host=" << callbackEndpoint_.host()
+        callback_(Resource<int>("$MARS_DHS_LOCALPORT", 0)),
+        callbackEndpoint_(computeEndpoint()) {
+        LOG_DEBUG_LIB(LibMetkit) << "Simple callback. local port=" << callback_.localPort() << " host=" << callbackEndpoint_.host()
                                  << " port=" << callbackEndpoint_.port() << std::endl;
     }
     explicit SimpleCallback(const Configuration&) : SimpleCallback() {}
@@ -105,6 +106,19 @@ private:
     net::EphemeralTCPServer callback_;
     Endpoint callbackEndpoint_;
 
+    Endpoint computeEndpoint() const {
+        static std::string callbackHost = Resource<std::string>("$MARS_DHS_CALLBACK_HOST", "");
+        static int callbackPort = Resource<int>("$MARS_DHS_CALLBACK_PORT", 0);
+
+        if (callbackHost.empty()) {
+            return Endpoint{net::IPAddress::hostAddress(callback_.localHost()).asString(), callback_.localPort()};
+        }
+        if (callbackPort == 0) {
+            return Endpoint{callbackHost, callback_.localPort()};
+        }
+        return Endpoint{callbackHost, callbackPort};
+    }
+
 public:
     static const ClassSpec&  classSpec() {
         static ClassSpec spec = {&BaseCallbackConnection::classSpec(), "SimpleCallback"};
@@ -370,7 +384,7 @@ Length DHSProtocol::retrieve(const MarsRequest& request)
 {
     Endpoint callbackEndpoint = callback_->endpoint();
 
-    Log::debug() << "DHSProtocol: call back on " << callbackEndpoint << std::endl;
+    LOG_DEBUG_LIB(LibMetkit) << "DHSProtocol: call back on " << callbackEndpoint << std::endl;
 
     task_.reset(new ClientTask(request, RequestEnvironment::instance().request(),
                                   callbackEndpoint.host(), callbackEndpoint.port()));
@@ -385,7 +399,7 @@ Length DHSProtocol::retrieve(const MarsRequest& request)
     while (wait(result)) {
     }
 
-    Log::debug() << "DHSProtocol::retrieve " << result << std::endl;
+    LOG_DEBUG_LIB(LibMetkit) << "DHSProtocol::retrieve " << result << std::endl;
     return result;
 }
 
@@ -393,8 +407,8 @@ void DHSProtocol::archive(const MarsRequest& request, const Length& size)
 {
     Endpoint callbackEndpoint = callback_->endpoint();
 
-    Log::debug() << "DHSProtocol::archive " << size << std::endl;
-    Log::debug() << "DHSProtocol: call back on " << callbackEndpoint << std::endl;
+    LOG_DEBUG_LIB(LibMetkit) << "DHSProtocol::archive " << size << std::endl;
+    LOG_DEBUG_LIB(LibMetkit) << "DHSProtocol: call back on " << callbackEndpoint << std::endl;
 
     task_.reset(new ClientTask(request, RequestEnvironment::instance().request(),
                                   callbackEndpoint.host(), callbackEndpoint.port()));
@@ -408,7 +422,7 @@ void DHSProtocol::archive(const MarsRequest& request, const Length& size)
     Length result = size;
     while (wait(result)) {
     }
-    Log::debug() << "DHSProtocol: archive completed." << std::endl;
+    LOG_DEBUG_LIB(LibMetkit) << "DHSProtocol: archive completed." << std::endl;
 }
 
 void DHSProtocol::cleanup()
@@ -488,7 +502,7 @@ bool DHSProtocol::wait(Length& size)
 
         char code = task_->receive(s);
 
-        Log::debug() << "DHSProtocol: code [" << code << "]" << std::endl;
+        LOG_DEBUG_LIB(LibMetkit) << "DHSProtocol: code [" << code << "]" << std::endl;
 
         std::string msg;
         long long bytes;
@@ -502,7 +516,7 @@ bool DHSProtocol::wait(Length& size)
         /* read source */
         case 'r':
             bytes = size;
-            Log::debug() << "DHSProtocol:r [" << bytes << "]" << std::endl;
+            LOG_DEBUG_LIB(LibMetkit) << "DHSProtocol:r [" << bytes << "]" << std::endl;
             s << bytes;
             sending_ = true;
             return false;
@@ -514,7 +528,7 @@ bool DHSProtocol::wait(Length& size)
 
         case 'w':
             s >> bytes;
-            Log::debug() << "DHSProtocol:w " << bytes << std::endl;
+            LOG_DEBUG_LIB(LibMetkit) << "DHSProtocol:w " << bytes << std::endl;
             size = bytes;
             return false;
 
@@ -555,7 +569,7 @@ bool DHSProtocol::wait(Length& size)
 
         case 'D': /* debug */
             s >> msg;
-            Log::debug() << msg << " [" << name_ << "]" << std::endl;
+            LOG_DEBUG_LIB(LibMetkit) << msg << " [" << name_ << "]" << std::endl;
             if (forward_) {
                 Log::userInfo() << msg << " [" << name_ << "]" << std::endl;
             }
