@@ -41,10 +41,8 @@ public:  // methods
 private:  // members
     std::string verb_ = "retrieve";
 
-    eckit::StringDict mapping_;  // mapping ODB column names to keys in MARS keywords
-
     bool one_                 = false;
-    bool mergeSimilarBlocks_  = false;
+    // bool mergeSimilarBlocks_  = false; // unused
     bool onlyConstantColumns_ = false;
 };
 
