@@ -192,10 +192,10 @@ CASE("test codessplitter unstr_latlot.tmpl Native") {
         MD_EXPECT_LONG(md, "shapeOfTheEarth", 6);
         MD_EXPECT_LONG(md, "numberOfGridUsed", 10);
         MD_EXPECT_LONG(md, "numberOfGridInReference", 1);
-        MD_EXPECT_STRING(md, "unstructuredGridType", "unknown");
+        MD_EXPECT_STRINGS(md, "unstructuredGridType", "unknown", "DART");
         MD_EXPECT_STRING(md, "unstructuredGridSubtype", "T");
         MD_EXPECT_STRING(md, "unstructuredGridUUID", "unknown");
-        MD_EXPECT_STRING(md, "gridName", "unknown");
+        MD_EXPECT_STRINGS(md, "gridName", "unknown", "DART_T");
         MD_EXPECT_STRING(md, "gridType", "unstructured_grid");
         MD_EXPECT_LONG(md, "section4Length", 34);
         MD_EXPECT_LONG(md, "NV", 0);
@@ -375,10 +375,10 @@ CASE("test codessplitter unstr_latlot.tmpl String") {
         MD_EXPECT_STRING(md, "numberOfGridUsed", "10");
         MD_EXPECT_STRING(md, "numberOfGridInReference", "1");
         MD_EXPECT_STRING(md, "uuidOfHGrid", "66a341d21dcf11b2880c0f1645f3d1dc");
-        MD_EXPECT_STRING(md, "unstructuredGridType", "unknown");
+        MD_EXPECT_STRINGS(md, "unstructuredGridType", "unknown", "DART");
         MD_EXPECT_STRING(md, "unstructuredGridSubtype", "T");
         MD_EXPECT_STRING(md, "unstructuredGridUUID", "unknown");
-        MD_EXPECT_STRING(md, "gridName", "unknown");
+        MD_EXPECT_STRINGS(md, "gridName", "unknown", "DART_T");
         MD_EXPECT_STRING(md, "gridType", "unstructured_grid");
         MD_EXPECT_STRING(md, "section4Length", "34");
         MD_EXPECT_STRING(md, "NV", "0");
